@@ -92,9 +92,6 @@ class Cell(object):
         if f_xml is not None:
             # Remove any existing formula when setting the value
             f_xml.getparent().remove(f_xml)
-            c_xml = self.ws.calc_chain.find('{0}c[@r="{1}"][@i="{2}"]'.format(SHEET_MAIN_NS, self.name, self.ws.id))
-            if c_xml is not None:
-                c_xml.getparent().remove(c_xml)
         v_xml = self.cell.find('{0}v'.format(SHEET_MAIN_NS))
         if v_xml is not None:
             if 't' in self.cell.attrib and self.cell.attrib['t'] == 's':  # value is from string table
